.. _roadmap:

###################
Development Roadmap
###################

1. Include simple examples that people should be able work through by hand
2. Example scripts and/or programs that expand on the tutorials to show users how to complete more complex end-to-end
   processing tasks
3. Expand the :mod:`regions<csep.core.regions>` to accommodate more complex regions, such as a quad-tree or triangulated
   mesh.


